@@ -525,7 +525,7 @@ public:
     {
         fDistinctUnionNum = distinctUnionNum;
     }
-    const uint8_t distinctUnionNum() const
+    uint8_t distinctUnionNum() const
     {
         return fDistinctUnionNum;
     }
@@ -574,7 +574,7 @@ public:
     {
         fHasOrderBy = hasOrderBy;
     }
-    const bool hasOrderBy() const
+    bool hasOrderBy() const
     {
         return fHasOrderBy;
     }
@@ -583,7 +583,7 @@ public:
     {
         fSpecHandlerProcessed = hand;
     }
-    const bool specHandlerProcessed() const
+    bool specHandlerProcessed() const
     {
         return fSpecHandlerProcessed;
     } 
@@ -772,6 +772,12 @@ public:
         return ((fSessionID & 0x80000000) != 0);
     }
 
+    virtual void setDynamicParseTreeVec(
+        const std::vector<execplan::ParseTree*>& dynamicParseTreeVec)
+    {
+        fDynamicParseTreeVec = dynamicParseTreeVec;
+    }
+
     /**
      * Protected stuff
      */
@@ -922,6 +928,8 @@ private:
     bool fIsDML;
 
     std::string fTimeZone;
+
+    std::vector<execplan::ParseTree*> fDynamicParseTreeVec;
 };
 
 /**
