@@ -39,7 +39,6 @@ Created 2/17/1996 Heikki Tuuri
 #include "btr0cur.h"
 #include "btr0pcur.h"
 #include "btr0btr.h"
-#include "ha0ha.h"
 #include "srv0mon.h"
 
 /** Is search system enabled.
@@ -1291,26 +1290,6 @@ retry:
 	ut_ad(block->page.id().space() == index->table->space_id);
 	ut_a(index_id == index->id);
 	ut_ad(!dict_index_is_ibuf(index));
-#ifdef UNIV_DEBUG
-	switch (dict_index_get_online_status(index)) {
-	case ONLINE_INDEX_CREATION:
-		/* The index is being created (bulk loaded). */
-	case ONLINE_INDEX_COMPLETE:
-		/* The index has been published. */
-	case ONLINE_INDEX_ABORTED:
-		/* Either the index creation was aborted due to an
-		error observed by InnoDB (in which case there should
-		not be any adaptive hash index entries), or it was
-		completed and then flagged aborted in
-		rollback_inplace_alter_table(). */
-		break;
-	case ONLINE_INDEX_ABORTED_DROPPED:
-		/* The index should have been dropped from the tablespace
-		already, and the adaptive hash index entries should have
-		been dropped as well. */
-		ut_error;
-	}
-#endif /* UNIV_DEBUG */
 
 	n_fields = block->curr_n_fields;
 	n_bytes = block->curr_n_bytes;
@@ -1656,7 +1635,6 @@ btr_search_build_page_hash_index(
 		for (ulint i = 0; i < n_cached; i++) {
 			ha_insert_for_fold(&part->table, part->heap,
 					   folds[i], block, recs[i]);
-			MONITOR_INC(MONITOR_ADAPTIVE_HASH_ROW_ADDED);
 		}
 	}
 
