@@ -141,7 +141,7 @@ wait_ex_event:	A thread may only wait on the wait_ex_event after it has
 rw_lock_stats_t		rw_lock_stats;
 
 /* The global list of rw-locks */
-rw_lock_list_t		rw_lock_list;
+ilist<rw_lock_t> rw_lock_list;
 ib_mutex_t		rw_lock_list_mutex;
 
 #ifdef UNIV_DEBUG
@@ -234,8 +234,10 @@ rw_lock_create_func(
 
 	lock->is_block_lock = 0;
 
+	ut_d(lock->created = true);
+
 	mutex_enter(&rw_lock_list_mutex);
-	UT_LIST_ADD_FIRST(rw_lock_list, lock);
+	rw_lock_list.push_front(*lock);
 	mutex_exit(&rw_lock_list_mutex);
 }
 
@@ -251,13 +253,15 @@ rw_lock_free_func(
 	ut_ad(rw_lock_validate(lock));
 	ut_a(lock->lock_word == X_LOCK_DECR);
 
+	ut_d(lock->created = false);
+
 	mutex_enter(&rw_lock_list_mutex);
 
 	os_event_destroy(lock->event);
 
 	os_event_destroy(lock->wait_ex_event);
 
-	UT_LIST_REMOVE(rw_lock_list, lock);
+	rw_lock_list.remove(*lock);
 
 	mutex_exit(&rw_lock_list_mutex);
 }
@@ -850,6 +854,8 @@ rw_lock_validate(
 {
 	ut_ad(lock);
 
+	ut_ad(lock->created);
+
 	int32_t lock_word = lock->lock_word;
 
 	ut_ad(lock->waiters < 2);
@@ -1095,17 +1101,15 @@ rw_lock_list_print_info(
 	      "RW-LATCH INFO\n"
 	      "-------------\n", file);
 
-	for (const rw_lock_t* lock = UT_LIST_GET_FIRST(rw_lock_list);
-	     lock != NULL;
-	     lock = UT_LIST_GET_NEXT(list, lock)) {
+	for (const rw_lock_t& lock : rw_lock_list) {
 
 		count++;
 
-		if (lock->lock_word != X_LOCK_DECR) {
+		if (lock.lock_word != X_LOCK_DECR) {
 
-			fprintf(file, "RW-LOCK: %p ", (void*) lock);
+			fprintf(file, "RW-LOCK: %p ", (void*) &lock);
 
-			if (int32_t waiters= lock->waiters) {
+			if (int32_t waiters= lock.waiters) {
 				fprintf(file, " (%d waiters)\n", waiters);
 			} else {
 				putc('\n', file);
@@ -1115,7 +1119,7 @@ rw_lock_list_print_info(
 
 			rw_lock_debug_mutex_enter();
 
-			for (info = UT_LIST_GET_FIRST(lock->debug_list);
+			for (info = UT_LIST_GET_FIRST(lock.debug_list);
 			     info != NULL;
 			     info = UT_LIST_GET_NEXT(list, info)) {
 
