@@ -377,10 +377,6 @@ trx_t *trx_create()
 	ut_ad(trx->lock.rec_cached == 0);
 	ut_ad(UT_LIST_GET_LEN(trx->lock.evicted_tables) == 0);
 
-#ifdef WITH_WSREP
-	trx->wsrep_event= NULL;
-#endif /* WITH_WSREP */
-
 	trx_sys.register_trx(trx);
 
 	return(trx);
@@ -392,25 +388,11 @@ trx_t *trx_create()
 */
 void trx_free(trx_t*& trx)
 {
-	ut_ad(!trx->declared_to_be_inside_innodb);
 	ut_ad(!trx->n_mysql_tables_in_use);
 	ut_ad(!trx->mysql_n_tables_locked);
 	ut_ad(!trx->internal);
 	ut_ad(!trx->mysql_log_file_name);
 
-	if (UNIV_UNLIKELY(trx->declared_to_be_inside_innodb)) {
-		ib::error() << "Freeing a trx ("
-			<< trx_get_id_for_print(trx) << ") which is declared"
-			" to be processing inside InnoDB";
-
-		trx_print(stderr, trx, 600);
-		putc('\n', stderr);
-
-		/* This is an error but not a fatal error. We must keep
-		the counters like srv_conc.n_active accurate. */
-		srv_conc_force_exit_innodb(trx);
-	}
-
 	if (trx->n_mysql_tables_in_use != 0
 	    || trx->mysql_n_tables_locked != 0) {
 
@@ -454,26 +436,26 @@ void trx_free(trx_t*& trx)
 #ifdef __SANITIZE_ADDRESS__
 	/* Unpoison the memory for innodb_monitor_set_option;
 	it is operating also on the freed transaction objects. */
-	MEM_UNDEFINED(&trx->mutex, sizeof trx->mutex);
-	/* For innobase_kill_connection() */
+	MEM_MAKE_ADDRESSABLE(&trx->mutex, sizeof trx->mutex);
 # ifdef WITH_WSREP
-	MEM_UNDEFINED(&trx->wsrep, sizeof trx->wsrep);
+	MEM_MAKE_ADDRESSABLE(&trx->wsrep, sizeof trx->wsrep);
 # endif
-	MEM_UNDEFINED(&trx->state, sizeof trx->state);
-	MEM_UNDEFINED(&trx->mysql_thd, sizeof trx->mysql_thd);
+	/* For innobase_kill_connection() */
+	MEM_MAKE_ADDRESSABLE(&trx->state, sizeof trx->state);
+	MEM_MAKE_ADDRESSABLE(&trx->mysql_thd, sizeof trx->mysql_thd);
 #endif
-#ifdef HAVE_valgrind
-	/* Unpoison the memory for innodb_monitor_set_option;
-	it is operating also on the freed transaction objects.
-	We checked that these were initialized in
-	trx_pools->mem_free(trx). */
-	UNIV_MEM_VALID(&trx->mutex, sizeof trx->mutex);
+#if defined HAVE_valgrind && !__has_feature(memory_sanitizer)
+	/* In Valgrind, we cannot cancel the effect of MEM_NOACCESS()
+	without changing the state of the V bits (indicating which
+	bits are initialized). We did invoke MEM_CHECK_DEFINED() in
+	trx_pools->mem_free(). */
+	MEM_MAKE_DEFINED(&trx->mutex, sizeof trx->mutex);
 	/* For innobase_kill_connection() */
 # ifdef WITH_WSREP
-	UNIV_MEM_VALID(&trx->wsrep, sizeof trx->wsrep);
+	MEM_MAKE_DEFINED(&trx->wsrep, sizeof trx->wsrep);
 # endif
-	UNIV_MEM_VALID(&trx->state, sizeof trx->state);
-	UNIV_MEM_VALID(&trx->mysql_thd, sizeof trx->mysql_thd);
+	MEM_MAKE_DEFINED(&trx->state, sizeof trx->state);
+	MEM_MAKE_DEFINED(&trx->mysql_thd, sizeof trx->mysql_thd);
 #endif
 
 	trx = NULL;
@@ -977,8 +959,9 @@ trx_start_low(
 	ut_a(trx->lock.table_locks.empty());
 
 	/* No other thread can access this trx object through rw_trx_hash,
-	still it can be found through trx_sys.trx_list, which means state
-	change must be protected by e.g. trx->mutex.
+	still it can be found through trx_sys.trx_list. Sometimes it's
+	possible to indirectly protect trx_t::state by freezing
+	trx_sys.trx_list.
 
 	For now we update it without mutex protection, because original code
 	did it this way. It has to be reviewed and fixed properly. */
@@ -1271,7 +1254,8 @@ trx_update_mod_tables_timestamp(
 		dict_table_t* table = it->first;
 		table->update_time = now;
 #ifdef UNIV_DEBUG
-		if (preserve_tables || table->get_ref_count()) {
+		if (preserve_tables || table->get_ref_count()
+		    || UT_LIST_GET_LEN(table->locks)) {
 			/* do not evict when committing DDL operations
 			or if some other transaction is holding the
 			table handle */
@@ -1280,7 +1264,11 @@ trx_update_mod_tables_timestamp(
 		/* recheck while holding the mutex that blocks
 		table->acquire() */
 		mutex_enter(&dict_sys.mutex);
-		if (!table->get_ref_count()) {
+		mutex_enter(&lock_sys.mutex);
+		const bool do_evict = !table->get_ref_count()
+			&& !UT_LIST_GET_LEN(table->locks);
+		mutex_exit(&lock_sys.mutex);
+		if (do_evict) {
 			dict_sys.remove(table, true);
 		}
 		mutex_exit(&dict_sys.mutex);
@@ -1343,9 +1331,9 @@ inline void trx_t::commit_in_memory(const mtr_t *mtr)
     /* This state change is not protected by any mutex, therefore
     there is an inherent race here around state transition during
     printouts. We ignore this race for the sake of efficiency.
-    However, the trx_sys_t::mutex will protect the trx_t instance
-    and it cannot be removed from the trx_list and freed
-    without first acquiring the trx_sys_t::mutex. */
+    However, the freezing of trx_sys.trx_list will protect the trx_t
+    instance and it cannot be removed from the trx_list and freed
+    without first unfreezing trx_list. */
     ut_ad(trx_state_eq(this, TRX_STATE_ACTIVE));
 
     MONITOR_INC(MONITOR_TRX_NL_RO_COMMIT);
@@ -1463,11 +1451,6 @@ inline void trx_t::commit_in_memory(const mtr_t *mtr)
       must_flush_log_later= true;
     else if (srv_flush_log_at_trx_commit)
       trx_flush_log_if_needed(commit_lsn, this);
-
-    /* Tell server some activity has happened, since the trx does
-    changes something. Background utility threads like master thread,
-    purge thread or page_cleaner thread might have some work to do. */
-    srv_active_wake_master_thread();
   }
 
   ut_ad(!rsegs.m_noredo.undo);
@@ -1823,11 +1806,6 @@ state_ok:
 		fputs(" recovered trx", f);
 	}
 
-	if (trx->declared_to_be_inside_innodb) {
-		fprintf(f, ", thread declared inside InnoDB %lu",
-			(ulong) trx->n_tickets_to_enter_innodb);
-	}
-
 	putc('\n', f);
 
 	if (trx->n_mysql_tables_in_use > 0 || trx->mysql_n_tables_locked > 0) {
